@@ -17,7 +17,9 @@
 #'    The cumulative flows restart every year and are only calculated in years with complete data.
 #'
 #' @inheritParams calc_annual_stats
-#' 
+#' @param months Numeric vector of months to add cumulative flows (e.g. \code{6:8} for Jun-Aug). Leave blank to accumulate 
+#'    all months (default \code{1:12}).
+#'    
 #' @return A tibble data frame of the source data with an additional column:
 #'   \item{Cumul_Volume_m3}{cumulative volumetric flows for each day for each year, in units of cubic metres}
 #'   
@@ -38,7 +40,8 @@ add_cumulative_volume <- function(data,
                                   values = Value,
                                   groups = STATION_NUMBER,
                                   station_number,
-                                  water_year_start = 1){
+                                  water_year_start = 1,
+                                  months = 1:12){
   
   
   
@@ -52,6 +55,7 @@ add_cumulative_volume <- function(data,
   }
   
   water_year_checks(water_year_start)
+  months_checks(months)
   
   
   ## FLOW DATA CHECKS AND FORMATTING
@@ -80,7 +84,8 @@ add_cumulative_volume <- function(data,
   # Fill missing dates, add date variables
   flow_data_temp <- analysis_prep(data = flow_data, 
                                   water_year_start = water_year_start)
-  
+  flow_data_temp <- dplyr::filter(flow_data_temp,
+                                  Month %in% months)
   
   ## ADD VOLUME COLUMN
   ## -----------------
