@@ -56,6 +56,7 @@ plot_annual_lowflows <- function(data,
                                  exclude_years,
                                  months = 1:12,
                                  ignore_missing = FALSE,
+                                 allowed_missing = ifelse(ignore_missing,100,0),
                                  log_discharge = FALSE,
                                  include_title = FALSE){
   
@@ -110,14 +111,8 @@ plot_annual_lowflows <- function(data,
                                         end_year = end_year,
                                         exclude_years = exclude_years, 
                                         months = months,
-                                        ignore_missing = ignore_missing)
-  
- 
-  
-  
-
-  ## SET ORDER
-  
+                                        ignore_missing = ignore_missing,
+                                        allowed_missing = allowed_missing)
   
   # Gather data and plot the minimums day
   lowflow_doy <- dplyr::select(lowflow_stats, STATION_NUMBER, Year, dplyr::contains("DoY"))
@@ -130,20 +125,20 @@ plot_annual_lowflows <- function(data,
   lowflow_doy <- dplyr::mutate(lowflow_doy, Statistic = paste0(gsub("_Day_DoY", "", Statistic), " Day Mininum"))
   lowflow_doy <- dplyr::mutate(lowflow_doy, Statistic = as.factor(Statistic))
   levels(lowflow_doy$Statistic) <- stat_levels
-
-
-
+  
+  
+  
   # Gather data and plot the minimums values
   lowflow_values <- dplyr::select(lowflow_stats, STATION_NUMBER, Year, dplyr::contains("Day"), 
                                   -dplyr::contains("DoY"), -dplyr::contains("Date"))
-
+  
   lowflow_values <- tidyr::gather(lowflow_values, Statistic, Value, -STATION_NUMBER, -Year)
   lowflow_values <- dplyr::mutate(lowflow_values, Statistic = substr(Statistic, 5, nchar(Statistic)))
   lowflow_values <- dplyr::mutate(lowflow_values, Statistic = paste0(gsub("_Day", "", Statistic), " Day Mininum"))
   lowflow_values <- dplyr::mutate(lowflow_values, Statistic = as.factor(Statistic))
   levels(lowflow_values$Statistic) <- stat_levels
-
-
+  
+  
   ## PLOT STATS
   ## ----------
   
@@ -155,56 +150,58 @@ plot_annual_lowflows <- function(data,
   # Create plots for each STATION_NUMBER in a tibble (see: http://www.brodrigues.co/blog/2017-03-29-make-ggplot2-purrr/)
   doy_plots <- dplyr::group_by(lowflow_doy, STATION_NUMBER)
   doy_plots <- tidyr::nest(doy_plots)
-  doy_plots <- dplyr::mutate(doy_plots,
-                              plot = purrr::map2(data, STATION_NUMBER, 
-        ~ggplot2::ggplot(data = ., ggplot2::aes(x = Year, y = Value, color = Statistic)) +
-          ggplot2::geom_line(alpha = 0.5, na.rm = TRUE)+
-          ggplot2::geom_point(na.rm = TRUE)+
-          ggplot2::facet_wrap(~Statistic, ncol = 1, strip.position = "top")+
-          ggplot2::scale_x_continuous(breaks = scales::pretty_breaks(n = 8))+
-          {if(length(unique(lowflow_doy$Year)) < 8) ggplot2::scale_x_continuous(breaks = unique(lowflow_doy$Year))}+
-          ggplot2::scale_y_continuous(breaks = scales::pretty_breaks(n = 6))+
-          ggplot2::ylab("Day of Year")+
-          ggplot2::xlab("Year")+
-         # ggplot2::scale_color_brewer(palette = "Set1") +
-          ggplot2::theme_bw() +
-          ggplot2::guides(colour = 'none')+
-          {if (include_title & .y != "XXXXXXX") ggplot2::ggtitle(paste(.y)) } +
-          ggplot2::theme(panel.border = ggplot2::element_rect(colour = "black", fill = NA, size = 1),
-                         panel.grid = ggplot2::element_line(size = .2),
-                         axis.title = ggplot2::element_text(size = 12),
-                         axis.text = ggplot2::element_text(size = 10),
-                         plot.title = ggplot2::element_text(hjust = 1, size = 9, colour = "grey25"),
-                         strip.background = ggplot2::element_blank(),
-                         strip.text = ggplot2::element_text(hjust = 0, face = "bold", size = 10))
-                              ))
+  doy_plots <- dplyr::mutate(
+    doy_plots,
+    plot = purrr::map2(data, STATION_NUMBER, 
+                       ~ggplot2::ggplot(data = ., ggplot2::aes(x = Year, y = Value, color = Statistic)) +
+                         ggplot2::geom_line(alpha = 0.5, na.rm = TRUE)+
+                         ggplot2::geom_point(na.rm = TRUE)+
+                         ggplot2::facet_wrap(~Statistic, ncol = 1, strip.position = "top")+
+                         ggplot2::scale_x_continuous(breaks = scales::pretty_breaks(n = 8))+
+                         {if(length(unique(lowflow_doy$Year)) < 8) ggplot2::scale_x_continuous(breaks = unique(lowflow_doy$Year))}+
+                         ggplot2::scale_y_continuous(breaks = scales::pretty_breaks(n = 6))+
+                         ggplot2::ylab("Day of Year")+
+                         ggplot2::xlab("Year")+
+                         # ggplot2::scale_color_brewer(palette = "Set1") +
+                         ggplot2::theme_bw() +
+                         ggplot2::guides(colour = 'none')+
+                         {if (include_title & .y != "XXXXXXX") ggplot2::ggtitle(paste(.y)) } +
+                         ggplot2::theme(panel.border = ggplot2::element_rect(colour = "black", fill = NA, size = 1),
+                                        panel.grid = ggplot2::element_line(size = .2),
+                                        axis.title = ggplot2::element_text(size = 12),
+                                        axis.text = ggplot2::element_text(size = 10),
+                                        plot.title = ggplot2::element_text(hjust = 1, size = 9, colour = "grey25"),
+                                        strip.background = ggplot2::element_blank(),
+                                        strip.text = ggplot2::element_text(hjust = 0, face = "bold", size = 10))
+    ))
   
   flow_plots <- dplyr::group_by(lowflow_values, STATION_NUMBER)
   flow_plots <- tidyr::nest(flow_plots)
-  flow_plots <- dplyr::mutate(flow_plots,
-                             plot = purrr::map2(data, STATION_NUMBER, 
-           ~ggplot2::ggplot(data = ., ggplot2::aes(x = Year, y = Value, color = Statistic)) +
-             ggplot2::geom_line(alpha = 0.5, na.rm = TRUE)+
-             ggplot2::geom_point(na.rm = TRUE)+
-             ggplot2::facet_wrap(~Statistic, ncol = 1, strip.position = "top")+
-             ggplot2::scale_x_continuous(breaks = scales::pretty_breaks(n = 8))+
-             {if(length(unique(lowflow_values$Year)) < 8) ggplot2::scale_x_continuous(breaks = unique(lowflow_values$Year))}+
-             ggplot2::scale_y_continuous(breaks = scales::pretty_breaks(n = 6))+
-             ggplot2::ylab(y_axis_title)+
-             ggplot2::xlab("Year")+
-             ggplot2::scale_color_brewer(palette = "Set1") +
-             ggplot2::theme_bw() +
-             ggplot2::guides(colour = 'none')+
-             {if (include_title & .y != "XXXXXXX") ggplot2::ggtitle(paste(.y)) } +
-             ggplot2::theme(panel.border = ggplot2::element_rect(colour = "black", fill = NA, size = 1),
-                            panel.grid = ggplot2::element_line(size = .2),
-                            axis.title = ggplot2::element_text(size = 12),
-                            axis.text = ggplot2::element_text(size = 10),
-                            plot.title = ggplot2::element_text(hjust = 1, size = 9, colour = "grey25"),
-                            strip.background = ggplot2::element_blank(),
-                            strip.text = ggplot2::element_text(hjust = 0, face = "bold", size = 10))
-                             ))
-           
+  flow_plots <- dplyr::mutate(
+    flow_plots,
+    plot = purrr::map2(data, STATION_NUMBER, 
+                       ~ggplot2::ggplot(data = ., ggplot2::aes(x = Year, y = Value, color = Statistic)) +
+                         ggplot2::geom_line(alpha = 0.5, na.rm = TRUE)+
+                         ggplot2::geom_point(na.rm = TRUE)+
+                         ggplot2::facet_wrap(~Statistic, ncol = 1, strip.position = "top")+
+                         ggplot2::scale_x_continuous(breaks = scales::pretty_breaks(n = 8))+
+                         {if(length(unique(lowflow_values$Year)) < 8) ggplot2::scale_x_continuous(breaks = unique(lowflow_values$Year))}+
+                         ggplot2::scale_y_continuous(breaks = scales::pretty_breaks(n = 6))+
+                         ggplot2::ylab(y_axis_title)+
+                         ggplot2::xlab("Year")+
+                         ggplot2::scale_color_brewer(palette = "Set1") +
+                         ggplot2::theme_bw() +
+                         ggplot2::guides(colour = 'none')+
+                         {if (include_title & .y != "XXXXXXX") ggplot2::ggtitle(paste(.y)) } +
+                         ggplot2::theme(panel.border = ggplot2::element_rect(colour = "black", fill = NA, size = 1),
+                                        panel.grid = ggplot2::element_line(size = .2),
+                                        axis.title = ggplot2::element_text(size = 12),
+                                        axis.text = ggplot2::element_text(size = 10),
+                                        plot.title = ggplot2::element_text(hjust = 1, size = 9, colour = "grey25"),
+                                        strip.background = ggplot2::element_blank(),
+                                        strip.text = ggplot2::element_text(hjust = 0, face = "bold", size = 10))
+    ))
+  
   
   # Create a list of named plots extracted from the tibble
   plots_1 <- flow_plots$plot
