@@ -64,6 +64,7 @@ plot_daily_cumulative_stats <- function(data,
                                         start_year,
                                         end_year,
                                         exclude_years, 
+                                        months = 1:12,
                                         log_discharge = FALSE,
                                         include_title = FALSE,
                                         add_year){
@@ -132,11 +133,12 @@ plot_daily_cumulative_stats <- function(data,
   daily_stats <- calc_daily_cumulative_stats(data = flow_data,
                                              percentiles = c(5,25,75,95),
                                              use_yield = use_yield, 
-                                             basin_area = ifelse(use_yield, basin_area, 0),
+                                             basin_area = basin_area,
                                              water_year_start = water_year_start,
                                              start_year = start_year,
                                              end_year = end_year,
-                                             exclude_years = exclude_years)
+                                             exclude_years = exclude_years,
+                                             months = months)
   
  
   
@@ -154,10 +156,12 @@ plot_daily_cumulative_stats <- function(data,
     
     # Add cumulative flows
     if (use_yield){
-      year_data <- add_cumulative_yield(data = year_data, water_year_start = water_year_start, basin_area = basin_area)
+      year_data <- add_cumulative_yield(data = year_data, water_year_start = water_year_start, basin_area = basin_area,
+                                        months = months)
       year_data$Cumul_Flow <- year_data$Cumul_Yield_mm
     } else {
-      year_data <- add_cumulative_volume(data = year_data, water_year_start = water_year_start)
+      year_data <- add_cumulative_volume(data = year_data, water_year_start = water_year_start,
+                                         months = months)
       year_data$Cumul_Flow <- year_data$Cumul_Volume_m3
     }
     
